#!/bin/bash
# maintainer         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# former             : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://www.openwall.com/john/
# last revised       : 20.07.2010

softname='john'
softversion='1.7.6'
packageversion='66.1'

arch='i486'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.openwall.com/john/g/john-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/lib/$softname
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
    |-----handy-ruler------------------------------------------------------|
john: John the Ripper (Password cracker)
john: 
john: John the Ripper is a fast password  cracker, currently available for
john: many  flavors  of  Unix (11 are officially  supported, not  counting 
john: different architectures), DOS, Win32, BeOS, and OpenVMS. Its primary
john: purpose  is to detect weak  Unix passwords. Besides several crypt(3)
john: password hash types  most commonly  found  on  various  Unix flavors
john: supported out of the box are Kerberos AFS. 
john: 
john:
john:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg

# build
cd $src/src

    make clean linux-x86-any
    cp -a ../run/*  $dest/usr/lib/$softname
    
# wrapper
cat << "EOF" > $dest/usr/bin/john
#!/bin/bash
# John The Ripper launcher
/usr/lib/john/john $@
EOF
chmod +x $dest/usr/bin/john

# add 'default' files
cd $src
    cp -a \
      doc/* \
      $dest/usr/doc/$softname-$softversion

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# perm fix
chmod 755 $dest/usr/lib/john/mailer

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/ap/$pkgname/build-john.sh > $package.src
echo $source >> $package.src

# erase src
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
